@@ -6,7 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-only
 */
 
-/**
+/*
  * This is a horrifically simple implementation of KSharedDataCache that is
  * basically missing the "shared" part to it, for use on Windows or other platforms
  * that don't support POSIX.
@@ -53,6 +53,11 @@ bool KSharedDataCache::insert(const QString &key, const QByteArray &data)
     return d->cache.insert(key, new QByteArray(data));
 }
 
+bool KSharedDataCache::remove(const QString &key)
+{
+    return d->cache.remove(key);
+}
+
 bool KSharedDataCache::find(const QString &key, QByteArray *destination) const
 {
     QByteArray *value = d->cache.object(key);
